ToastCoordinateSystem
=====================

.. currentmodule:: toasty.toast

.. autoclass:: ToastCoordinateSystem
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ToastCoordinateSystem.ASTRONOMICAL
      ~ToastCoordinateSystem.PLANETARY

   .. rubric:: Attributes Documentation

   .. autoattribute:: ASTRONOMICAL
   .. autoattribute:: PLANETARY
